==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/AccessManager.h <==
// public class soot.jimple.toolkits.invoke.AccessManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class abf461c423270dea soot_jimple_toolkits_invoke_AccessManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_AccessManager_H_
#define _JC_soot_jimple_toolkits_invoke_AccessManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_ClassMember$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs	_jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$refs	_jc_soot_jimple_toolkits_invoke_AccessManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs	_jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$object	_jc_soot_jimple_toolkits_invoke_AccessManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vmethods	_jc_soot_jimple_toolkits_invoke_AccessManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtable	_jc_soot_jimple_toolkits_invoke_AccessManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtype	_jc_soot_jimple_toolkits_invoke_AccessManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_AccessManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_AccessManager$object *);

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$ensureAccess$9b764d0366cb23a4(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$ensureAccess$25dfb94e31a15e0c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$isAccessLegal$319ed028474cafd1(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *);
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$isAccessLegal$0f45cdb2bcae22a3(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootClass$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vmethods	soot_jimple_toolkits_invoke_AccessManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$refs {
    _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs	soot_jimple_toolkits_invoke_AccessManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs	soot_jimple_toolkits_invoke_AccessManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_AccessManager$object {
	_jc_soot_jimple_toolkits_invoke_AccessManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_AccessManager$vtype _jc_soot_jimple_toolkits_invoke_AccessManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_AccessManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_AccessManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_AccessManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/AccessManager.h <==
// public class soot.jimple.toolkits.invoke.AccessManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class abf461c423270dea soot_jimple_toolkits_invoke_AccessManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_AccessManager_H_
#define _JC_soot_jimple_toolkits_invoke_AccessManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_ClassMember$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs	_jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$refs	_jc_soot_jimple_toolkits_invoke_AccessManager$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs	_jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_AccessManager$object	_jc_soot_jimple_toolkits_invoke_AccessManager$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vmethods	_jc_soot_jimple_toolkits_invoke_AccessManager$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtable	_jc_soot_jimple_toolkits_invoke_AccessManager$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtype	_jc_soot_jimple_toolkits_invoke_AccessManager$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_AccessManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_AccessManager$object *) _JC_JCNI_ATTR;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$ensureAccess$9b764d0366cb23a4(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$ensureAccess$25dfb94e31a15e0c(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootClass$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$isAccessLegal$319ed028474cafd1(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_invoke_AccessManager$method$isAccessLegal$0f45cdb2bcae22a3(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vmethods	soot_jimple_toolkits_invoke_AccessManager;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_AccessManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$refs {
    _jc_soot_jimple_toolkits_invoke_AccessManager$sub_refs	soot_jimple_toolkits_invoke_AccessManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_AccessManager$sub_nonrefs	soot_jimple_toolkits_invoke_AccessManager;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_AccessManager$object {
	_jc_soot_jimple_toolkits_invoke_AccessManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_AccessManager$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_AccessManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_AccessManager$vtype _jc_soot_jimple_toolkits_invoke_AccessManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_AccessManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_AccessManager$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_AccessManager_H_ */
